Package: transcriptogramer
Type: Package
Title: Transcriptional analysis based on transcriptograms
Version: 1.35.0
Date: 2019-12-13
Authors@R: c(
    person("Diego", "Morais", email = "vinx@ufrn.edu.br",
    role = c("aut", "cre")),
    person("Rodrigo", "Dalmolin", email = "rodrigo.dalmolin@imd.ufrn.br",
    role = "aut"))
Description: R package for transcriptional analysis based on transcriptograms,
    a method to analyze transcriptomes that projects expression values on a
    set of ordered proteins, arranged such that the probability that gene
    products participate in the same metabolic pathway exponentially decreases
    with the increase of the distance between two proteins of the ordering.
    Transcriptograms are, hence, genome wide gene expression profiles that
    provide a global view for the cellular metabolism, while indicating gene
    sets whose expressions are altered.
Depends: R (>= 3.4), methods
License: GPL (>= 2)
Encoding: UTF-8
LazyData: true
biocViews: Software, Network, Visualization, SystemsBiology,
        GeneExpression, GeneSetEnrichment, GraphAndNetwork, Clustering,
        DifferentialExpression, Microarray, RNASeq, Transcription,
        ImmunoOncology
Imports: biomaRt, data.table, doSNOW, foreach, ggplot2, graphics,
        grDevices, igraph, limma, parallel, progress, RedeR, snow,
        stats, tidyr, topGO
RoxygenNote: 6.1.1
VignetteBuilder: knitr
Suggests: BiocStyle, knitr, rmarkdown, RUnit, BiocGenerics
SystemRequirements: Java Runtime Environment (>= 6)
URL: https://github.com/arthurvinx/transcriptogramer
BugReports: https://github.com/arthurvinx/transcriptogramer/issues
git_url: https://git.bioconductor.org/packages/transcriptogramer
git_branch: devel
git_last_commit: d14dd1a
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 01:49:27 UTC; biocbuild
Author: Diego Morais [aut, cre],
  Rodrigo Dalmolin [aut]
Maintainer: Diego Morais <vinx@ufrn.edu.br>
