# Generated by roxygen2: do not edit by hand

export("radius<-")
export(DE)
export(Terms)
export(clusterEnrichment)
export(clusterVisualization)
export(connectivityProperties)
export(differentiallyExpressed)
export(enrichmentPlot)
export(orderingProperties)
export(radius)
export(transcriptogramPreprocess)
export(transcriptogramStep1)
export(transcriptogramStep2)
exportClasses(Transcriptogram)
importClassesFrom(topGO,topGOdata)
importFrom(RedeR,RedPort)
importFrom(RedeR,addGraph)
importFrom(RedeR,att.setv)
importFrom(RedeR,calld)
importFrom(RedeR,relax)
importFrom(RedeR,selectNodes)
importFrom(RedeR,subg)
importFrom(biomaRt,getBM)
importFrom(biomaRt,useMart)
importFrom(doSNOW,registerDoSNOW)
importFrom(foreach,"%dopar%")
importFrom(foreach,foreach)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_linetype_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(grDevices,rainbow)
importFrom(graphics,plot)
importFrom(igraph,E)
importFrom(igraph,V)
importFrom(igraph,count_triangles)
importFrom(igraph,graph.data.frame)
importFrom(limma,contrasts.fit)
importFrom(limma,decideTests)
importFrom(limma,eBayes)
importFrom(limma,lmFit)
importFrom(limma,makeContrasts)
importFrom(methods,new)
importFrom(parallel,detectCores)
importFrom(progress,progress_bar)
importFrom(snow,makeSOCKcluster)
importFrom(snow,parLapply)
importFrom(snow,stopCluster)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,smooth.spline)
importFrom(tidyr,gather)
importFrom(topGO,GenTable)
importFrom(topGO,annFUN.gene2GO)
importFrom(topGO,genesInTerm)
importFrom(topGO,groupGOTerms)
importFrom(topGO,runTest)
importFrom(utils,head)
